from PyTASTileType import *
from NeighborGlues import *

# Defines the temperature the simulator will use while adding tiles from this module
TEMPERATURE = 2

#  GetSeed is the function called by the simulator to get the definitions and
#  locations of tiles in the seed
def GetSeed():
    ## Seeds
    t = PyTASTileType()
    t.sides[N] = t.sides[E] = Glue(2,"1")
    t.sides[S] = Glue(2,"foo")
    t.sides[W] = Glue(2,"bar")
    t.label = "SEED1"
    t.name = "Seed"
    
    tLocation = (0,0,0)
    return ((t,tLocation),)

#  GetTileTypes is the function called by the simulator as it encounters frontier locations
def GetTileTypes(nbrGlues):
    returnSet = set()
    
    ## Handle y axis wall
    if nbrGlues.sides[S] is not None:
        if nbrGlues.sides[S].strength == 2:
            t = PyTASTileType()
            t.name = "LEFT_WALL"
            t.sides[N].strength = 2
            t.sides[N].label = "1"
            t.sides[E].strength = 1 #Pass a 1 into the structure
            t.sides[E].label = "1"
            t.sides[S].strength = 2
            t.sides[S].label = "1"
            t.color = "RED"
            t.label = "Left"
            returnSet.add(t)
    
    ## Handle x axis wall
    if nbrGlues.sides[W] is not None:
        if nbrGlues.sides[W].strength == 2:
            t = PyTASTileType()
            t.name = "BOTTOM_WALL"
            t.sides[N].strength = 1 #Pass a 1 into the structure
            t.sides[N].label = "1"
            t.sides[E] = t.sides[W] = Glue(2,"1") #Quicker way to write it, but note both reference same glue object
            t.color = "RED"
            t.label = "Bottom"
            returnSet.add(t)
            
    #Handle interior (XOR operation) tiles
    if (nbrGlues.sides[W] is not None) and (nbrGlues.sides[S] is not None):
        inLeft = int(nbrGlues.sides[W].label)
        inBottom = int(nbrGlues.sides[S].label)
        #print("inLeft:" + str(inLeft) + ":, inBottom:" + str(inBottom) + ":")
        t = PyTASTileType()
        ## Top and Right push the xor operation to later tiles
        t.sides[N] = t.sides[E] = Glue(1,str(inLeft ^ inBottom))
        ## Left and bottom just match input glues
        t.sides[S] = nbrGlues.sides[S].Copy()
        t.sides[W] = nbrGlues.sides[W].Copy()
        ## Visuals
        if (inLeft ^ inBottom):
            t.label = "1"
            t.color = "RED"
        else:
            t.label = "0"
            t.color = "WHITE"

        t.name = t.sides[W].label + "xor" + t.sides[S].label
        returnSet.add(t)
        
    if returnSet != set():
        return returnSet
    else:
        return None
